@@ -2,6 +2,7 @@ package Example::Controller;
 
 use Moose;
 extends 'Catalyst::ControllerPerContext';
+with 'Catalyst::ControllerRole::At';
 
 around gather_default_action_roles => sub {
   my ($orig, $self, %args) = @_;
@@ -9,7 +10,9 @@ around gather_default_action_roles => sub {
   push @roles, 'Catalyst::ActionRole::CurrentView'
     if $args{attributes}->{View};
   push @roles, 'Catalyst::ActionRole::RequestModel'
-    if $args{attributes}->{RequestModel} || $args{attributes}->{QueryModel};
+    if $args{attributes}->{RequestModel} || 
+      $args{attributes}->{QueryModel} || 
+        $args{attributes}->{BodyModel};
   return @roles;
 };
 
