@@ -3,8 +3,8 @@ package Example::View::HTML::Contacts;
 use Moo;
 use Example::Syntax;
 use Example::View::HTML
-  -tags => qw(div a fieldset legend br b u button form_for table thead tbody tfoot trow th td link_to),
-  -util => qw(path $sf),
+  -tags => qw(link_to div a fieldset legend br b u button form_for table thead tbody tfoot trow th td link_to),
+  -helpers => qw(path edit_entity_path list_entities_path init_entity_path $sf),
   -views => 'HTML::Page', 'HTML::Navbar';
 
 has 'list' => (is=>'ro', required=>1, from=>'controller', handles=>['pager']);
@@ -22,14 +22,14 @@ sub render($self, $c) {
             ],
           tbody { repeat=>$self->list }, sub ($self, $item, $idx) {
             trow [
-              td a +{ href=>path('edit', [$item->id]) }, $item->$sf('{:first_name} {:last_name}'),
+              td link_to edit_entity_path($item), $item->$sf('{:first_name} {:last_name}'),
             ],
           },
           tfoot { if=>$self->pager->last_page > 1  },
             td {colspan=>2, style=>'background:white'},
               ["Page: ", $self->pagelist ],
         ],
-        a { href=>path('init'), role=>'button', class=>'btn btn-lg btn-primary btn-block' }, "Create a new Contact",
+        a { href=>init_entity_path, role=>'button', class=>'btn btn-lg btn-primary btn-block' }, "Create a new Contact",
      ],
   };
 }
@@ -45,8 +45,8 @@ sub page_window_info :Renders ($self) {
 sub pagelist :Renders ($self) {
   my @page_html = ();
   foreach my $page (1..$self->pager->last_page) {
-    push @page_html, a {href=>path('list', +{'contact.page'=>$page}), style=>'margin: .5rem'},
-      $page == $self->pager->current_page ? b u $page : $page;
+    my $page_for_display = $page == $self->pager->current_page ? b u $page : $page;
+    push @page_html, link_to list_entities_path(+{'contact.page'=>$page}), {style=>'margin: .5rem'}, $page_for_display; 
   }
   return @page_html;
 }
