@@ -66,8 +66,6 @@ sub no_errors {
   return !shift->has_errors;
 }
 
-has 'validated' => (is=>'rw', required=>1, init_args=>undef, default=>0);
-has 'skip_validation' =>  (is=>'rw', required=>1, init_args=>undef, default=>0);
 has '_context' => (is=>'rw', required=>0, predicate=>'has_context');
 
 sub get_context { shift->_context }
@@ -79,6 +77,17 @@ sub context {
   return $self;
 }
 
+has '_csrf_token' => (is=>'rw', required=>0, init_arg=>'csrf_token', predicate=>'has_csrf_token');
+
+sub csrf_token {
+  my ($self, $arg) = @_;
+  $self->_csrf_token($arg) if $arg;
+  return $arg ? $self : $self->_csrf_token;
+}
+
+has 'validated' => (is=>'rw', required=>1, init_args=>undef, default=>0);
+has 'skip_validation' =>  (is=>'rw', required=>1, init_args=>undef, default=>0);
+
 sub skip_validate {
   my ($self) = @_;
   $self->skip_validation(1);
